Crate kcr_stunner_l7mp_io

Crate kcr_stunner_l7mp_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the stunner.l7mp.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

stunner.l7mp.io/v1

  • Dataplane
  • GatewayConfig
  • StaticService
  • UDPRoute

stunner.l7mp.io/v1alpha1

  • Dataplane
  • GatewayConfig
  • StaticService

Modules

v1
v1alpha1