This crate contains kube-rs compatible bindings for Kubernetes custom resources for the stunner.l7mp.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
stunner.l7mp.io/v1
DataplaneGatewayConfigStaticServiceUDPRoute
stunner.l7mp.io/v1alpha1
DataplaneGatewayConfigStaticService